@@ -436,9 +436,9 @@ terms_sp <- function(formula) {
   if (!length(out)) {
     return(NULL)
   }
-  uni_mo <- trim_wsp(get_matches_expr(regex_sp("mo"), out))
-  uni_me <- trim_wsp(get_matches_expr(regex_sp("me"), out))
-  uni_mi <- trim_wsp(get_matches_expr(regex_sp("mi"), out))
+  uni_mo <- get_matches_expr(regex_sp("mo"), out)
+  uni_me <- get_matches_expr(regex_sp("me"), out)
+  uni_mi <- get_matches_expr(regex_sp("mi"), out)
   # remove the intercept as it is handled separately
   out <- str2formula(c("0", out))
   attr(out, "int") <- FALSE
@@ -805,7 +805,7 @@ combine_formulas <- function(formula1, formula2, lhs = "", update = FALSE) {
 has_terms <- function(formula) {
   stopifnot(is.formula(formula))
   terms <- try(terms(rhs(formula)), silent = TRUE)
-  is(terms, "try-error") ||
+  is_try_error(terms) ||
     length(attr(terms, "term.labels")) ||
     length(attr(terms, "offset"))
 }
@@ -921,6 +921,7 @@ all_terms <- function(x) {
 
 # generate a regular expression to extract special terms
 # @param type one or more special term types to be extracted
+# TODO: rule out expressions such as mi(y) + mi(x)
 regex_sp <- function(type = "all") {
   choices <- c("all", "sp", "sm", "gp", "cs", "mmc", "ac", all_sp_types())
   type <- unique(match.arg(type, choices, several.ok = TRUE))
@@ -956,7 +957,7 @@ find_terms <- function(x, type, complete = TRUE, ranef = FALSE) {
   if (is.formula(x)) {
     x <- all_terms(x)
   } else {
-    x <- as.character(x)
+    x <- trim_wsp(as.character(x))
   }
   complete <- as_one_logical(complete)
   ranef <- as_one_logical(ranef)
@@ -969,13 +970,14 @@ find_terms <- function(x, type, complete = TRUE, ranef = FALSE) {
   if (complete) {
     matches <- lapply(out, get_matches_expr, pattern = regex)
     # each term may contain only one special function call
-    inv <- out[lengths(matches) > 1L]
-    if (!length(inv)) {
+    invalid <- out[lengths(matches) > 1L]
+    if (!length(invalid)) {
       # each term must be exactly equal to the special function call
-      inv <- out[trim_wsp(unlist(matches)) != out]
+      invalid <- out[unlist(matches) != out]
     }
-    if (length(inv)) {
-      stop2("The term '", inv[1], "' is invalid in brms syntax.")
+    # TODO: some terms can be part of I() calls (#1520); reflect this here?
+    if (length(invalid)) {
+      stop2("The term '", invalid[1], "' is invalid in brms syntax.")
     }
   }
   out
@@ -1010,7 +1012,7 @@ has_intercept <- function(formula) {
   } else {
     formula <- as.formula(formula)
     try_terms <- try(terms(formula), silent = TRUE)
-    if (is(try_terms, "try-error")) {
+    if (is_try_error(try_terms)) {
       out <- FALSE
     } else {
       out <- as.logical(attr(try_terms, "intercept"))
@@ -1036,12 +1038,12 @@ has_rsv_intercept <- function(formula, has_intercept = NULL) {
     return(.has_rsv_intercept(formula, has_intercept))
   }
   formula <- try(as.formula(formula), silent = TRUE)
-  if (is(formula, "try-error")) {
+  if (is_try_error(formula)) {
     return(FALSE)
   }
   if (is.null(has_intercept)) {
     try_terms <- try(terms(formula), silent = TRUE)
-    if (is(try_terms, "try-error")) {
+    if (is_try_error(try_terms)) {
       return(FALSE)
     }
     has_intercept <- has_intercept(try_terms)
