@@ -14,6 +14,11 @@ test_that("brmsformula validates formulas of auxiliary parameters", {
                "Additional formulas must be named")
 })
 
+test_that("brmsformula detects use if '~~'", {
+  # checks fix of issue #749
+  expect_error(bf(y~~x), "~~")
+})
+
 test_that("brmsformula does not change a 'brmsformula' object", {
   form <- bf(y ~ a, sigma ~ 1)
   expect_identical(form, bf(form))
@@ -37,11 +42,11 @@ test_that("brmsformula detects auxiliary parameter equations", {
 test_that("update_adterms works correctly", {
   form <- y | trials(size) ~ x
   expect_equal(
-    update_adterms(form, ~ trials(10)), 
+    update_adterms(form, ~ trials(10)),
     y | trials(10) ~ x
   )
   expect_equal(
-    update_adterms(form, ~ weights(w)), 
+    update_adterms(form, ~ weights(w)),
     y | trials(size) + weights(w) ~ x
   )
   expect_equal(
@@ -54,7 +59,3 @@ test_that("update_adterms works correctly", {
   )
 })
 
-test_that("deprecated 'cbind' syntax still works", {
-  expect_equal(suppressWarnings(bf(cbind(y1, y2) ~ x)), bf(mvbind(y1, y2) ~ x))
-})
-
